@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 def parse_nick_modes(mode_string):
     """Parse a nick mode string.
 
@@ -15,6 +13,7 @@ def parse_nick_modes(mode_string):
 
     return _parse_modes(mode_string, "")
 
+
 def parse_channel_modes(mode_string):
     """Parse a channel mode string.
 
@@ -29,6 +28,7 @@ def parse_channel_modes(mode_string):
     """
     return _parse_modes(mode_string, "bklvohq")
 
+
 def _parse_modes(mode_string, unary_modes=""):
     """
     Parse the mode_string and return a list of triples.
@@ -56,10 +56,9 @@ def _parse_modes(mode_string, unary_modes=""):
     This function never throws an error:
 
     >>> import random
-    >>> import six
     >>> def random_text(min_len = 3, max_len = 80):
     ...     len = random.randint(min_len, max_len)
-    ...     chars_to_choose = [six.unichr(x) for x in range(0,1024)]
+    ...     chars_to_choose = [chr(x) for x in range(0,1024)]
     ...     chars = (random.choice(chars_to_choose) for x in range(len))
     ...     return ''.join(chars)
     >>> def random_texts(min_len = 3, max_len = 80):
